@@ -26,6 +26,8 @@
 
 #define MALLOC_FLAG(A) ((A & 1) ? MY_THREAD_SPECIFIC : 0)
 
+#define TRASH_MEM(X) TRASH_FREE(((char*)(X) + ((X)->size-(X)->left)), (X)->left)
+
 /*
   Initialize memory root
 
@@ -72,12 +74,13 @@ void init_alloc_root(MEM_ROOT *mem_root, size_t block_size,
   if (pre_alloc_size)
   {
     if ((mem_root->free= mem_root->pre_alloc=
-	 (USED_MEM*) my_malloc(pre_alloc_size+ ALIGN_SIZE(sizeof(USED_MEM)),
-			       MYF(my_flags))))
+         (USED_MEM*) my_malloc(pre_alloc_size + ALIGN_SIZE(sizeof(USED_MEM)),
+                               MYF(my_flags))))
     {
       mem_root->free->size= pre_alloc_size+ALIGN_SIZE(sizeof(USED_MEM));
       mem_root->free->left= pre_alloc_size;
       mem_root->free->next= 0;
+      TRASH_MEM(mem_root->free);
     }
   }
 #endif
@@ -146,6 +149,7 @@ void reset_root_defaults(MEM_ROOT *mem_root, size_t block_size,
         mem->left= pre_alloc_size;
         mem->next= *prev;
         *prev= mem_root->pre_alloc= mem; 
+        TRASH_MEM(mem);
       }
       else
       {
@@ -244,6 +248,7 @@ void *alloc_root(MEM_ROOT *mem_root, size_t length)
     next->size= get_size;
     next->left= get_size-ALIGN_SIZE(sizeof(USED_MEM));
     *prev=next;
+    TRASH_MEM(next);
   }
 
   point= (uchar*) ((char*) next+ (next->size-next->left));
@@ -312,8 +317,6 @@ void *multi_alloc_root(MEM_ROOT *root, ...)
   DBUG_RETURN((void*) start);
 }
 
-#define TRASH_MEM(X) TRASH(((char*)(X) + ((X)->size-(X)->left)), (X)->left)
-
 /* Mark all data in blocks free for reusage */
 
 static inline void mark_blocks_free(MEM_ROOT* root)
